@@ -270,7 +270,7 @@ class AgentLifeCycle:
         username, password = base64.b64decode(token['authorizationData'][0]['authorizationToken']).decode().split(':')
         registry = token['authorizationData'][0]['proxyEndpoint']        
 
-        docker_client = docker.from_env()
+        docker_client = docker.APIClient(base_url='unix://var/run/docker.sock')
         try:
             result = docker_client.login(username, password, registry=registry, reauth=True)
         except docker.errors.APIError:
@@ -278,12 +278,16 @@ class AgentLifeCycle:
 
         images = set(object._docker_images.values())
         for image_name in images:
-            print(image_name, end = ' - ')
+            
             try:
-                result = docker_client.images.pull(image_name)
-                print(f"{bcolors.OKBLUE}OK{bcolors.ENDC}")
-            except:
-                print(f"{bcolors.FAIL}FAILED{bcolors.ENDC}")
+                i = 0
+                for status in docker_client.pull(image_name, stream = True, decode = True):
+                    if("progress" not in status):
+                        status["progress"] = ""
+                    print('\r' + image_name + ' - ' + status["status"] + " " + status["progress"], end="")                    
+                print(f"\r{image_name} - {bcolors.OKBLUE}OK{bcolors.ENDC}\033[K")                
+            except docker.errors.ImageNotFound:
+                print(f"\r{image_name} - {bcolors.FAIL}FAILED{bcolors.ENDC}\033[K")
 
         print("Info: Run `cognicept restart` to redeploy updated agents.")
         
