@@ -8,6 +8,11 @@ from pathlib import Path
 import os
 import sys
 import re
+import requests
+import getpass
+import jwt
+import time
+
 
 
 class Configuration:
@@ -84,5 +89,51 @@ class Configuration:
                     file.write(key + '=' + value + '\n')
         except IOError:
             print("Could not write into `" + object.env_path + "`. Please check write permission or run with `sudo`.")
+    
+    def cognicept_login(object):
+        print("Please enter your Cognicept credentials.")
+        
+        username = input("Username: ")
+        try: 
+            password = getpass.getpass() 
+        except Exception as error: 
+            print('Error when reading password.')
+            return False
+        
+        try:
+            resp = requests.post('https://dev.cognicept.systems/api/v1/user/login', json = {"username": username, "password": password}, timeout = 5)
+        except requests.exceptions.Timeout:
+            print("Cognicept REST API error: time out.")
+            return
+        except requests.exceptions.TooManyRedirects:
+            print("Cognicept REST API error: Wrong endpoint.")
+            return
+        except requests.exceptions.RequestException as e:
+            print("Cognicept REST API error")
+            raise SystemExit(e)
 
+        if resp.status_code != 200:
+            print('Login error: wrong credentials.')
+            return False
+        
+        object.config["COGNICEPT_JWT"] = resp.json()["access_token"]
+        object.save_config()
+
+        return True
+
+    def get_cognicept_jwt(object):
+        if "COGNICEPT_JWT" in object.config:
+            # check expiration of the current token
+            jwt_decoded = jwt.decode(object.config["COGNICEPT_JWT"], verify=False)
+            if ( jwt_decoded["exp"] >  time.time()):
+                # if not expired return token
+                return object.config["COGNICEPT_JWT"]
+            else:
+                print("Cognicept login expired.")
+        # try to login if token exists or expired
+        if(object.cognicept_login()):
+            return object.config["COGNICEPT_JWT"]
+        else:
+            # if all fails return empty string
+            return ""
       
\ No newline at end of file
